@@ -1,21 +1,7 @@
-extern crate chrono;
-extern crate clap;
-extern crate msi;
-
-use chrono::{DateTime, NaiveDateTime, Utc};
 use clap::{App, Arg, SubCommand};
 use std::cmp;
 use std::io::{self, Read, Seek};
-use std::time::{SystemTime, UNIX_EPOCH};
-
-fn to_datetime(timestamp: SystemTime) -> DateTime<Utc> {
-    let delta = timestamp.duration_since(UNIX_EPOCH).expect("duration_since");
-    let naive = NaiveDateTime::from_timestamp(
-        delta.as_secs() as i64,
-        delta.subsec_nanos(),
-    );
-    DateTime::<Utc>::from_utc(naive, Utc)
-}
+use time::OffsetDateTime;
 
 fn pad(mut string: String, fill: char, width: usize) -> String {
     while string.len() < width {
@@ -40,7 +26,7 @@ fn print_summary_info<F>(package: &msi::Package<F>) {
         println!("      Author: {}", author);
     }
     if let Some(uuid) = summary_info.uuid() {
-        println!("        UUID: {}", uuid.to_hyphenated());
+        println!("        UUID: {}", uuid.hyphenated());
     }
     if let Some(arch) = summary_info.arch() {
         println!("        Arch: {}", arch);
@@ -52,7 +38,7 @@ fn print_summary_info<F>(package: &msi::Package<F>) {
         println!("    Language: {}", tags.join(", "));
     }
     if let Some(timestamp) = summary_info.creation_time() {
-        println!("  Created at: {}", to_datetime(timestamp));
+        println!("  Created at: {}", OffsetDateTime::from(timestamp));
     }
     if let Some(app_name) = summary_info.creating_application() {
         println!("Created with: {}", app_name);
