@@ -34,14 +34,20 @@ pub enum ColumnType {
 }
 
 impl ColumnType {
+    #[allow(clippy::if_same_then_else)]
     fn from_bitfield(type_bits: i32) -> io::Result<ColumnType> {
         let field_size = (type_bits & COL_FIELD_SIZE_MASK) as usize;
         if (type_bits & COL_STRING_BIT) != 0 {
             Ok(ColumnType::Str(field_size))
-        } else if field_size == 2 {
-            Ok(ColumnType::Int16)
         } else if field_size == 4 {
             Ok(ColumnType::Int32)
+        } else if field_size == 2 {
+            Ok(ColumnType::Int16)
+        } else if field_size == 1 {
+            // Some implementations seem to set the integer field size to 1 for
+            // certain columns, but still store the data with 2 bytes?  See
+            // https://github.com/mdsteele/rust-msi/issues/8.
+            Ok(ColumnType::Int16)
         } else {
             invalid_data!(
                 "Invalid field size for integer column ({})",
@@ -190,16 +196,20 @@ impl Column {
     }
 
     pub(crate) fn with_name_prefix(&self, prefix: &str) -> Column {
-        Column {
-            name: format!("{}.{}", prefix, self.name),
-            coltype: self.coltype,
-            is_localizable: self.is_localizable,
-            is_nullable: self.is_nullable,
-            is_primary_key: self.is_primary_key,
-            value_range: self.value_range,
-            foreign_key: self.foreign_key.clone(),
-            category: self.category,
-            enum_values: self.enum_values.clone(),
+        if prefix.is_empty() {
+            self.clone()
+        } else {
+            Column {
+                name: format!("{}.{}", prefix, self.name),
+                coltype: self.coltype,
+                is_localizable: self.is_localizable,
+                is_nullable: self.is_nullable,
+                is_primary_key: self.is_primary_key,
+                value_range: self.value_range,
+                foreign_key: self.foreign_key.clone(),
+                category: self.category,
+                enum_values: self.enum_values.clone(),
+            }
         }
     }
 
@@ -309,7 +319,7 @@ impl Column {
                 ColumnType::Int16 | ColumnType::Int32 => false,
                 ColumnType::Str(max_len) => {
                     if let Some(category) = self.category {
-                        if !category.validate(&string) {
+                        if !category.validate(string) {
                             return false;
                         }
                     }
