@@ -278,7 +278,7 @@ impl<F: Read + Seek> Package<F> {
                 Some(ptype) => ptype,
                 None => invalid_data!(
                     "Unrecognized package CLSID ({})",
-                    clsid.to_hyphenated()
+                    clsid.hyphenated()
                 ),
             }
         };
@@ -354,8 +354,8 @@ impl<F: Read + Seek> Package<F> {
                         cols.insert(col_index, (col_name, type_bits));
                     } else {
                         invalid_data!(
-                            "_Columns mentions table {:?}, which \
-                                       isn't in _Tables",
+                            "_Columns mentions table {:?}, which isn't in \
+                             _Tables",
                             table_name
                         );
                     }
@@ -406,8 +406,7 @@ impl<F: Read + Seek> Package<F> {
                 || column_specs.keys().next_back() != Some(&num_columns)
             {
                 invalid_data!(
-                    "Table {:?} does not have a complete set \
-                               of columns",
+                    "Table {:?} does not have a complete set of columns",
                     table_name
                 );
             }
@@ -446,7 +445,7 @@ impl<F: Read + Seek> Package<F> {
                     let enum_values = value_refs[8].to_value(&string_pool);
                     if !enum_values.is_null() {
                         let enum_values: Vec<&str> =
-                            enum_values.as_str().unwrap().split(";").collect();
+                            enum_values.as_str().unwrap().split(';').collect();
                         builder = builder.enum_values(&enum_values);
                     }
                 }
@@ -581,8 +580,7 @@ impl<F: Read + Write + Seek> Package<F> {
         }
         if !columns.iter().any(Column::is_primary_key) {
             invalid_input!(
-                "Cannot create a table without at least one \
-                            primary key column"
+                "Cannot create a table without at least one primary key column"
             );
         }
         {
@@ -594,8 +592,8 @@ impl<F: Read + Write + Seek> Package<F> {
                 }
                 if column_names.contains(name) {
                     invalid_input!(
-                        "Cannot create a table with multiple \
-                                    columns with the same name ({:?})",
+                        "Cannot create a table with multiple columns with the \
+                         same name ({:?})",
                         name
                     );
                 }
@@ -976,136 +974,6 @@ mod tests {
             .collect();
         assert_eq!(values, vec![(1, -5), (2, 42), (3, -5)]);
     }
-
-    #[test]
-    fn select_rows() {
-        let cursor = Cursor::new(Vec::new());
-        let mut package =
-            Package::create(PackageType::Installer, cursor).expect("create");
-        let columns = vec![
-            Column::build("Foo").primary_key().int16(),
-            Column::build("Bar").string(16),
-            Column::build("Baz").nullable().int32(),
-        ];
-        package.create_table("Quux", columns).expect("create_table");
-        package
-            .insert_rows(
-                Insert::into("Quux")
-                    .row(vec![
-                        Value::Int(1),
-                        Value::Str("spam".to_string()),
-                        Value::Int(0),
-                    ])
-                    .row(vec![
-                        Value::Int(2),
-                        Value::Str("eggs".to_string()),
-                        Value::Null,
-                    ])
-                    .row(vec![
-                        Value::Int(3),
-                        Value::Str("bacon".to_string()),
-                        Value::Int(0),
-                    ])
-                    .row(vec![
-                        Value::Int(4),
-                        Value::Str("spam".to_string()),
-                        Value::Int(17),
-                    ]),
-            )
-            .expect("insert_rows");
-
-        let rows = package
-            .select_rows(
-                Select::table("Quux")
-                    .columns(&["Bar", "Foo"])
-                    .with(Expr::col("Baz").eq(Expr::integer(0))),
-            )
-            .expect("select_rows");
-        let values: Vec<(String, i32)> = rows
-            .map(|row| {
-                (
-                    row[0].as_str().unwrap().to_string(),
-                    row[1].as_int().unwrap(),
-                )
-            })
-            .collect();
-        assert_eq!(
-            values,
-            vec![("spam".to_string(), 1), ("bacon".to_string(), 3)]
-        );
-    }
-
-    #[test]
-    fn join_tables() {
-        let cursor = Cursor::new(Vec::new());
-        let mut package =
-            Package::create(PackageType::Installer, cursor).expect("create");
-        let columns = vec![
-            Column::build("Foo").primary_key().int16(),
-            Column::build("Bar").int16(),
-        ];
-        package.create_table("Foobar", columns).unwrap();
-        package
-            .insert_rows(
-                Insert::into("Foobar")
-                    .row(vec![Value::Int(1), Value::Int(17)])
-                    .row(vec![Value::Int(2), Value::Int(42)])
-                    .row(vec![Value::Int(3), Value::Int(17)]),
-            )
-            .unwrap();
-        let columns = vec![
-            Column::build("Baz").primary_key().int16(),
-            Column::build("Foo").int16(),
-        ];
-        package.create_table("Bazfoo", columns).unwrap();
-        package
-            .insert_rows(
-                Insert::into("Bazfoo")
-                    .row(vec![Value::Int(4), Value::Int(42)])
-                    .row(vec![Value::Int(5), Value::Int(13)])
-                    .row(vec![Value::Int(6), Value::Int(17)]),
-            )
-            .unwrap();
-        {
-            let rows = package
-                .select_rows(
-                    Select::table("Foobar")
-                        .inner_join(
-                            Select::table("Bazfoo"),
-                            Expr::col("Foobar.Bar")
-                                .eq(Expr::col("Bazfoo.Foo")),
-                        )
-                        .columns(&["Foobar.Foo", "Bazfoo.Baz"]),
-                )
-                .expect("select_rows");
-            let values: Vec<(i32, i32)> = rows
-                .map(|row| {
-                    (row[0].as_int().unwrap(), row[1].as_int().unwrap())
-                })
-                .collect();
-            assert_eq!(values, vec![(1, 6), (2, 4), (3, 6)]);
-        }
-        {
-            let rows = package
-                .select_rows(
-                    Select::table("Bazfoo")
-                        .left_join(
-                            Select::table("Foobar"),
-                            Expr::col("Foobar.Bar")
-                                .eq(Expr::col("Bazfoo.Foo")),
-                        )
-                        .columns(&["Bazfoo.Baz", "Foobar.Foo"]),
-                )
-                .expect("select_rows");
-            let values: Vec<(i32, Option<i32>)> = rows
-                .map(|row| (row[0].as_int().unwrap(), row[1].as_int()))
-                .collect();
-            assert_eq!(
-                values,
-                vec![(4, Some(2)), (5, None), (6, Some(1)), (6, Some(3))]
-            );
-        }
-    }
 }
 
 // ========================================================================= //
