@@ -153,8 +153,8 @@ impl Insert {
         for values in self.new_rows.iter() {
             if values.len() != table.columns().len() {
                 invalid_input!(
-                    "Table {:?} has {} columns, but a row with {} \
-                                values was provided",
+                    "Table {:?} has {} columns, but a row with {} values was \
+                     provided",
                     self.table_name,
                     table.columns().len(),
                     values.len()
@@ -184,8 +184,8 @@ impl Insert {
                     .collect();
                 if rows_map.contains_key(&keys) {
                     invalid_data!(
-                        "Malformed table {:?} contains \
-                                   multiple rows with key {:?}",
+                        "Malformed table {:?} contains multiple rows with \
+                         key {:?}",
                         self.table_name,
                         keys
                     );
@@ -203,8 +203,7 @@ impl Insert {
                 .collect();
             if rows_map.contains_key(&keys) {
                 already_exists!(
-                    "Table {:?} already contains a row with \
-                                 key {:?}",
+                    "Table {:?} already contains a row with key {:?}",
                     self.table_name,
                     keys
                 );
@@ -320,7 +319,7 @@ impl Join {
                         }))
                         .collect();
                 let table = Table::new(
-                    "<InnerJoin>".to_string(),
+                    String::new(),
                     columns,
                     string_pool.long_string_refs(),
                 );
@@ -360,7 +359,7 @@ impl Join {
                     }))
                     .collect();
                 let table = Table::new(
-                    "<LeftJoin>".to_string(),
+                    String::new(),
                     columns,
                     string_pool.long_string_refs(),
                 );
@@ -406,8 +405,8 @@ impl Join {
 impl fmt::Display for Join {
     fn fmt(&self, formatter: &mut fmt::Formatter) -> Result<(), fmt::Error> {
         match self {
-            &Join::Table(ref table_name) => table_name.fmt(formatter),
-            &Join::Inner(ref lhs, ref rhs, ref on) => {
+            Join::Table(ref table_name) => table_name.fmt(formatter),
+            Join::Inner(ref lhs, ref rhs, ref on) => {
                 lhs.format_for_join(formatter)?;
                 formatter.write_str(" INNER JOIN ")?;
                 rhs.format_for_join(formatter)?;
@@ -415,7 +414,7 @@ impl fmt::Display for Join {
                 on.fmt(formatter)?;
                 Ok(())
             }
-            &Join::Left(ref lhs, ref rhs, ref on) => {
+            Join::Left(ref lhs, ref rhs, ref on) => {
                 lhs.format_for_join(formatter)?;
                 formatter.write_str(" LEFT JOIN ")?;
                 rhs.format_for_join(formatter)?;
@@ -547,11 +546,8 @@ impl Select {
                 .iter()
                 .map(|&index| table.columns()[index].clone())
                 .collect();
-            table = Table::new(
-                "<Select>".to_string(),
-                columns,
-                table.long_string_refs(),
-            );
+            table =
+                Table::new(String::new(), columns, table.long_string_refs());
             for value_refs in rows.iter_mut() {
                 *value_refs = column_indices
                     .iter()
@@ -591,7 +587,7 @@ impl fmt::Display for Select {
                 } else {
                     comma = true;
                 }
-                formatter.write_str(&column_name)?;
+                formatter.write_str(column_name)?;
             }
         }
         formatter.write_str(" FROM ")?;
@@ -740,7 +736,7 @@ impl fmt::Display for Update {
             } else {
                 comma = true;
             }
-            formatter.write_str(&column_name)?;
+            formatter.write_str(column_name)?;
             formatter.write_str(" = ")?;
             value.fmt(formatter)?;
         }
